#include <iostream>

#include "_PLEASE_PYPROJECT_NAME_.hpp"

int main() {
    std::cout << "_PLEASE_PYPROJECT_NAME_ World!!" << std::endl;
    return 0;
}
